summaryrefslogtreecommitdiff
path: root/deps/uv/test/test-fs.c
diff options
context:
space:
mode:
authorBen Noordhuis <info@bnoordhuis.nl>2012-06-26 23:38:35 +0200
committerBen Noordhuis <info@bnoordhuis.nl>2012-06-26 23:38:35 +0200
commit1e50282ae8672ea2b6ea320e74389160bec951f0 (patch)
treee5534318d1513f29cc92cec81b0b0172e86ceb84 /deps/uv/test/test-fs.c
parent69f594d22ccca81d76396b52c1c8ce11115882dc (diff)
downloadandroid-node-v8-1e50282ae8672ea2b6ea320e74389160bec951f0.tar.gz
android-node-v8-1e50282ae8672ea2b6ea320e74389160bec951f0.tar.bz2
android-node-v8-1e50282ae8672ea2b6ea320e74389160bec951f0.zip
deps: upgrade libuv to 4d42af2
Diffstat (limited to 'deps/uv/test/test-fs.c')
-rw-r--r--deps/uv/test/test-fs.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/deps/uv/test/test-fs.c b/deps/uv/test/test-fs.c
index 36b68f3033..4b6d847f45 100644
--- a/deps/uv/test/test-fs.c
+++ b/deps/uv/test/test-fs.c
@@ -1224,10 +1224,10 @@ TEST_IMPL(fs_symlink) {
* We just pass the test and bail out early if we get ENOTSUP.
*/
return 0;
- } else if (uv_last_error(loop).sys_errno_ == ERROR_PRIVILEGE_NOT_HELD) {
+ } else if (uv_last_error(loop).code == UV_EPERM) {
/*
* Creating a symlink is only allowed when running elevated.
* We pass the test and bail out early if we get ERROR_PRIVILEGE_NOT_HELD.
*/
return 0;
}
@@ -1224,10 +1224,10 @@ TEST_IMPL(fs_symlink) {
/*
* Creating a symlink is only allowed when running elevated.
- * We pass the test and bail out early if we get ERROR_PRIVILEGE_NOT_HELD.
+ * We pass the test and bail out early if we get UV_EPERM.
*/
return 0;